'------------------------------------------------------------------------
'  ParadiseBroadband.vbs (v1.11)
'------------------------------------------------------------------------
'
' Retreives the local, international and total traffic usage for a
' paradise.net.nz ADSL or cable account.
'
' NOTES:- Set your username, password and quota below for this script to 
'	work correctly.
'
' 	- Execute the "updateUsage" function to update your Paradise
' 	usage. Ignore any warnings from antivirus software that this 
'	is a malicious script (it just writes a small .tmp file to your
'	Configs directory to save bandwidth)
'
'	- The "updateUsage" function should only be run every 60 min in
'	Samurize; Paradise only update your stats every 60 min and it
'	is a waste of bandwidth checking the usage every say 5min! Set
'	the other functions to update more often (say every 5 min) to
' 	ensure the usage is kept up-to-date.
'
' Special Thanks to:
'
' Ba'alzaman	- for the idea and suggestions/advice on how to make the
'		script more efficient :)
'
' Cowboy	- for lending his Paradise account for testing purposes
'
' Version History:
'
' Changes in v1.11:
' ----------------
'
' - fixed a problem with Paradise users that have less than 4 billing
'   periods on their usage page (thanks BF Jax)
'
' Changes in v1.1:
' ----------------
'
' - added extra functions by request of Drgnfire (getPeriodEndDate, 
'   trafficRemaining, getUsageLeftPerDay, getUsageUsedPerDay)
'
'								-NeM
'------------------------------------------------------------------------

'========================================================================
' ENTER YOUR ACCOUNT DETAILS HERE:
' --------------------------------

USER_NAME = "username"	' your Paradise account user name
PASSWORD = "password"	' your Paradise account password

MONTHLY_QUOTA = 10240	' How many megabytes of data you get per billing
			' period eg. 10GB = 10240MB

'========================================================================

' =============================================================
' PREFERENCES
' ===========
'
' Please choose the style you want the date to appear as.
' (NOTE: this is for the formattedDate function only)
'
' eg. for the 21st of Febuary 2003:
' (1) 21 Feb
' (2) 21 Feb 03
' (3) 21/02
' (4) 21/02/03

DATE_STYLE = 1
' =============================================================

' =============================================================
' How many decimal places you want the per-day stats rounded to

PRECISION = 2
' =============================================================

'DO NOT CHANGE THE FOLLOWING DEFINITIONS:
'#######################################################
TMP_FILE = "C:\Program Files\Samurize\ParadiseADSL.tmp"
TMP_FILE2 = "C:\Program Files\Samurize\ParadiseTextFile.tmp"
PRE_TRAFFIC = "<td align=""RIGHT"" bgcolor=""#555555"">"
'#######################################################

' === FUNCTIONS CALLED BY SAMURIZE ===

Function usageByTempFile()

	updateUsage()

	usage = getLocalTraffic() & vbCrlf & getInternationalTraffic() & vbCrlf & getTrafficRemaining() & vbCrlf & getPeriodEndDate & vbCrlf & formattedDate() & vbCrlf & getUsageLeftPerDay() & getUsageUsedPerDay() & vbCrlf &  getTotalTraffic() 

	set fs=CreateObject("Scripting.FileSystemObject")
	set f=fs.CreateTextFile(TMP_FILE2,true)
	f.write(usage)
	f.close
	set f=nothing
	set fs=nothing

	usageByTempFile = "OK"
	

End Function

Function getTotalTraffic()
	getTotalTraffic = getTraffic(3)
End Function

Function getPercentTraffic()
	getPercentTraffic = getTotalTraffic() / MONTHLY_QUOTA * 100
End Function

Function getLocalTraffic()
	getLocalTraffic = getTraffic(2)
End Function

Function getInternationalTraffic()
	getInternationalTraffic = getTraffic(1)
End Function

Function getTrafficRemaining()
	stringTraffic = getTraffic(3)
	getTrafficRemaining =  MONTHLY_QUOTA - CDbl(stringTraffic)
End Function

Function getPeriodEndDate()

	Dim strAllInfo
	
	' WAIT
	'Set WshShell = CreateObject("WScript.Shell")	
	'WshShell.Run "wait.vbs",1,True

	strAllInfo = readFile(TMP_FILE)

	checkFile = InStr(strAllInfo, "Equivalent")

	If checkFile > 0 Then

		' cut past all the links
		Do
			strAllInfo = Mid(strAllInfo, InStr(strAllInfo, "href=")+5)
		Loop Until InStr(strAllInfo, "href=") <= 0

		strAllInfo = Mid(strAllInfo, InStr(strAllInfo, " to ")+4)

		getPeriodEndDate = Mid(strAllInfo, 1, InStr(strAllInfo, "</a>")-1)

	Else
		getPeriodEndDate = "error"
		Exit Function
	End If

End Function


Function formattedDate()

	style = getPeriodEndDate()

	If DATE_STYLE > 2 Then
		dateString = mid(style, 9, 2) & "/" & mid(style, 6, 2)
		If DATE_STYLE = 4 Then
			dateString = dateString & "/" & mid(style, 3, 2)
		End If
	End If

	If DATE_STYLE < 3 Then
		dateString = mid(style, 9, 2) & " " & numToMonthName(CInt(mid(style, 6, 2)))
		If DATE_STYLE = 2 Then
			dateString = dateString & " " & mid(style, 3, 2)
		End If
	End If

	formattedDate = dateString

End Function


Function getUsageLeftPerDay()

	currentDate = Date()

	If Mid(currentDate, 2, 1) = "/" Then
		' add a 0 to the front of the date 
		currentDate = "0" & currentDate
	End If
		
	periodEnd = getPeriodEndDate()
	getUsageLeftPerDay = currentDate

	peMonth = CInt(mid(periodEnd, 6, 2))
	peDay = CInt(mid(periodEnd, 9, 2))

	currentMonth = CInt(mid(currentDate, 4, 2))
	currentDay = CInt(mid(currentDate, 1, 2))


	If currentMonth = peMonth Then
		' Same month
		daysLeft = peDay - currentDay + 1
	Else
		'different months
		daysLeft = peDay + numDaysInMonth(currentMonth) - currentDay + 1

	End If

	If daysLeft = 0 Then
		getUsageLeftPerDay = "-"
	Else
		getUsageLeftPerDay = round((getTrafficRemaining() / daysLeft), PRECISION)
	End If

End Function


Function getUsageUsedPerDay()

	currentDate = Date()
	periodEnd = getPeriodEndDate()

	If Mid(currentDate, 2, 1) = "/" Then
		' add a 0 to the front of the date 
		currentDate = "0" & currentDate
	End If

	peMonth = CInt(mid(periodEnd, 6, 2))
	peDay = CInt(mid(periodEnd, 9, 2))

	currentMonth = CInt(mid(currentDate, 4, 2))
	currentDay = CInt(mid(currentDate, 1, 2))

	If currentMonth = peMonth Then
		' Same month
		daysUsed = 28 - (peDay - currentDay)
	Else
		'different months
		daysUsed = 28 - (peDay + numDaysInMonth(currentMonth) - currentDay)
	End If

	If daysUsed < 1 Then
		daysUsed = 1
	End If

	getUsageUsedPerDay = round((getTotalTraffic() / daysUsed), PRECISION)

End Function


Function updateUsage()

	dim fs,f,htmlResult



	htmlResult = ReturnHTML("https://" & USER_NAME & ":" & PASSWORD & "@www.paradise.net.nz/cgi-bin/members/usage/show-volume-usage?")

	checkFile = InStr(htmlResult, "<title>paradise.net - Volume Detail</title>")

	If checkFile > 0 Then

		' Minimise the temp file size and read/write times
		htmlResult = Mid(htmlResult, InStr(htmlResult, "Equivalent"))
		htmlResult = Mid(htmlResult, 1, InStr(htmlResult, "</table>"))

		set fs=CreateObject("Scripting.FileSystemObject")
		set f=fs.CreateTextFile(TMP_FILE,true)
		f.write(htmlResult)
		f.close
		set f=nothing
		set fs=nothing

		updateUsage = "Paradise usage successfully updated."

	Else
		updateUsage = "Error retreiving usage. Check your username and password."
	End If

End Function


' === END OF FUNCTIONS CALLED BY SAMURIZE ===


Private Function getTraffic(j)

	' WAIT
	'Set WshShell = CreateObject("WScript.Shell")	
	'WshShell.Run "wait.vbs",1,True

	dim htmlResult, strAllInfo

	htmlResult = readFile(TMP_FILE)

	strAllInfo = htmlResult

	checkFile = InStr(htmlResult, "Equivalent")

	If checkFile > 0 Then

		If InStr(strAllInfo, PRE_TRAFFIC) = 0 Then
			' The new billing period hasn't been posted yet
			PRE_TRAFFIC = "<td align=""RIGHT"" bgcolor=""#333333"">"
		ENd If

		' cut past all the links
		Do
			strAllInfo = Mid(strAllInfo, InStr(strAllInfo, "href=")+5)
		Loop Until InStr(strAllInfo, "href=") <= 0

		' skip to traffic data
		For i = 1 to j
			strAllInfo = Mid(strAllInfo, InStr(strAllInfo, PRE_TRAFFIC)+Len(PRE_TRAFFIC))
		Next

		getTraffic = Mid(strAllInfo, 1, InStr(strAllInfo, "</td>")-1)
		

	Else
		getTraffic = "error"
		Exit Function
	End If

End Function


Private Function numDaysInMonth(monthNo)

	currentYear = CInt(mid(Date(), 7, 4))

	Select Case monthNo
		Case 1
			numDaysInMonth = 31 ' Jan
		Case 2
			If (currentYear/4 - Int(currentYear/4)) = 0 Then
				' Leap year
				numDaysInMonth = 29
			Else 
				' non-leap year
				numDaysInMonth = 28
			End If
		Case 3
			numDaysInMonth = 31 ' Mar
		Case 4
			numDaysInMonth = 30 ' Apr
		Case 5
			numDaysInMonth = 31 ' May
		Case 6
			numDaysInMonth = 30 ' Jun
		Case 7
			numDaysInMonth = 31 ' Jul
		Case 8
			numDaysInMonth = 31 ' Aug
		Case 9
			numDaysInMonth = 30 ' Sept
		Case 10
			numDaysInMonth = 31 ' Oct
		Case 11
			numDaysInMonth = 30 ' Nov
		Case 12
			numDaysInMonth = 31 ' Dec

	End Select
End Function


Private Function readFile(fileName)

	dim contents

	Set fs = CreateObject ("Scripting.FileSystemObject")
        If (fs.FileExists(TMP_FILE)) Then
		Set filePath = fs.GetFile(TMP_FILE)
		set File = filePath.OpenAsTextStream (1, -2)

		contents = file.readall

		File.Close ' Closes the file
		Set filePath = nothing
		Set fs = nothing
		Set File = nothing
	Else 
		Exit Function
        End If

	' return file contents
	readFile = contents

End Function


Private Function numToMonthName(num)

	Select Case num

	Case 1
		numToMonthName = "Jan"
	Case 2
		numToMonthName = "Feb"
	Case 3
		numToMonthName = "Mar"
	Case 4
		numToMonthName = "Apr"
	Case 5
		numToMonthName = "May"
	Case 6
		numToMonthName = "Jun"
	Case 7
		numToMonthName = "Jul"
	Case 8
		numToMonthName = "Aug"
	Case 9
		numToMonthName = "Sep"
	Case 10
		numToMonthName = "Oct"
	Case 11
		numToMonthName = "Nov"
	Case 12
		numToMonthName = "Dec"

	End Select

End Function


Private Function ReturnHTML(sURL)
	Dim objXMLHTTP,HTML
	Set objXMLHTTP = CreateObject("Microsoft.XMLHTTP")
	objXMLHTTP.Open "GET", sURL, False
	objXMLHTTP.Send
	HTML = objXMLHTTP.responseBody
	Set objRS = CreateObject("ADODB.Recordset")
	objRS.Fields.Append "txt", 200, 45000, &H00000080
	objRS.Open
	objRS.AddNew
	objRS.Fields("txt").AppendChunk HTML
	ReturnHTML = objRS("txt").Value
	objRS.Close
	Set objRS = Nothing
	Set objXMLHTTP = Nothing
End Function
